@@ -1,10 +1,10 @@
 #!/usr/bin/env python
 
 
-import json
+from .base import TelegramObject
 
 
-class Audio(object):
+class Audio(TelegramObject):
     def __init__(self,
                  file_id,
                  duration,
@@ -22,14 +22,11 @@ class Audio(object):
                      mime_type=data.get('mime_type', None),
                      file_size=data.get('file_size', None))
 
-    def to_json(self):
-        json_data = {'file_id': self.file_id,
-                     'duration': self.duration}
+    def to_dict(self):
+        data = {'file_id': self.file_id,
+                'duration': self.duration}
         if self.mime_type:
-            json_data['mime_type'] = self.mime_type
+            data['mime_type'] = self.mime_type
         if self.file_size:
-            json_data['file_size'] = self.file_size
-        return json.dumps(json_data)
-
-    def __str__(self):
-        return self.to_json()
+            data['file_size'] = self.file_size
+        return data
