@@ -32,8 +32,9 @@ class Document(TelegramObject):
                         file_size=data.get('file_size', None))
 
     def to_dict(self):
-        data = {'file_id': self.file_id,
-                'thumb': self.thumb.to_dict()}
+        data = {'file_id': self.file_id}
+        if self.thumb:
+            data['thumb'] = self.thumb.to_dict()
         if self.file_name:
             data['file_name'] = self.file_name
         if self.mime_type:
