@@ -1,10 +1,10 @@
 #!/usr/bin/env python
 
 
-import json
+from .base import TelegramObject
 
 
-class Location(object):
+class Location(TelegramObject):
     def __init__(self,
                  longitude,
                  latitude):
@@ -16,10 +16,7 @@ class Location(object):
         return Location(longitude=data.get('longitude', None),
                         latitude=data.get('latitude', None))
 
-    def to_json(self):
-        json_data = {'longitude': self.longitude,
-                     'latitude': self.latitude}
-        return json.dumps(json_data)
-
-    def __str__(self):
-        return self.to_json()
+    def to_dict(self):
+        data = {'longitude': self.longitude,
+                'latitude': self.latitude}
+        return data
