@@ -1,10 +1,10 @@
 #!/usr/bin/env python
 
 
-import json
+from .base import TelegramObject
 
 
-class Sticker(object):
+class Sticker(TelegramObject):
     def __init__(self,
                  file_id,
                  width,
@@ -31,14 +31,11 @@ class Sticker(object):
                        thumb=thumb,
                        file_size=data.get('file_size', None))
 
-    def to_json(self):
-        json_data = {'file_id': self.file_id,
-                     'width': self.width,
-                     'height': self.height,
-                     'thumb': self.thumb.to_json()}
+    def to_dict(self):
+        data = {'file_id': self.file_id,
+                'width': self.width,
+                'height': self.height,
+                'thumb': self.thumb.to_dict()}
         if self.file_size:
-            json_data['file_size'] = self.file_size
-        return json.dumps(json_data)
-
-    def __str__(self):
-        return self.to_json()
+            data['file_size'] = self.file_size
+        return data
