@@ -1,10 +1,10 @@
 #!/usr/bin/env python
 
 
-import json
+from .base import TelegramObject
 
 
-class Update(object):
+class Update(TelegramObject):
     def __init__(self,
                  update_id,
                  message=None):
@@ -22,11 +22,8 @@ class Update(object):
         return Update(update_id=data.get('update_id', None),
                       message=message)
 
-    def to_json(self):
-        json_data = {'update_id': self.update_id}
+    def to_dict(self):
+        data = {'update_id': self.update_id}
         if self.message:
-            json_data['message'] = self.message.to_json()
-        return json.dumps(json_data)
-
-    def __str__(self):
-        return self.to_json()
+            data['message'] = self.message.to_dict()
+        return data
