@@ -1,10 +1,10 @@
 #!/usr/bin/env python
 
 
-import json
+from .base import TelegramObject
 
 
-class User(object):
+class User(TelegramObject):
     def __init__(self,
                  id,
                  first_name,
@@ -30,14 +30,11 @@ class User(object):
                     last_name=data.get('last_name', None),
                     username=data.get('username', None))
 
-    def to_json(self):
-        json_data = {'id': self.id,
-                     'first_name': self.first_name}
+    def to_dict(self):
+        data = {'id': self.id,
+                'first_name': self.first_name}
         if self.last_name:
-            json_data['last_name'] = self.last_name
+            data['last_name'] = self.last_name
         if self.username:
-            json_data['username'] = self.username
-        return json.dumps(json_data)
-
-    def __str__(self):
-        return self.to_json()
+            data['username'] = self.username
+        return data
